@@ -62,7 +62,7 @@ int dialog_msgbox(const char *title, const char *prompt, int height, int width,
 		gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(w)->vbox),
 				   hbox,
 				   TRUE, TRUE, GNOME_PAD);
-		gtk_window_position(GTK_WINDOW(w), GTK_WIN_POS_CENTER);
+		gtk_window_set_position(GTK_WINDOW(w), GTK_WIN_POS_CENTER);
 		gtk_signal_connect(GTK_OBJECT(w), "destroy",
 			GTK_SIGNAL_FUNC(cancelled), NULL);
 		gtk_signal_connect(GTK_OBJECT(w), "clicked",
