@@ -185,7 +185,7 @@ gint delete_event_cb(GtkWidget *w, gpointer who_cares, GtkWidget **me) {
 	gtk_widget_destroy(*me);
 	*me = NULL;
 	
-	return TRUE;  /* stop default delete_event handlers */
+	return TRUE;
 }
 
 void prop_destroy_cb(GtkWidget *w, PropertyUI *data) {
@@ -537,7 +537,7 @@ void apply_changes_cb(GnomePropertyBox *pbox, gint page, PropertyUI *pui) {
 			
 			def_font = new_font;
 			
-			free(def_font_name);
+			g_free(def_font_name);
 			
 			def_font_name = g_strdup(gnome_font_picker_get_font_name
 									 (GNOME_FONT_PICKER(pui->font_button)));
@@ -585,19 +585,29 @@ void cleanup_cb(GnomeMDI *mdi) {
 	gtk_main_quit();
 }
 
+void child_changed_cb(GnomeMDI *mdi, HexDocument *doc) {
+	create_dialog_title(find_dialog.window, _("GHex (%s): Find Data"));
+	create_dialog_title(replace_dialog.window, _("GHex (%s): Find & Replace Data"));
+	create_dialog_title(jump_dialog.window, _("GHex (%s): Jump To Byte"));
+}
+
 void view_changed_cb(GnomeMDI *mdi, GtkHex *old_view) {
 	GnomeApp *app;
 	GtkWidget *shell, *item;
 	gint pos;
-	
+	gint group_item;
+
 	if(mdi->active_view == NULL)
 		return;
 
 	app = gnome_mdi_get_app_from_view(mdi->active_view);
 	
-	shell = gnome_app_find_menu_pos(app->menubar, _("Edit/Group Data As/"), &pos);
-	
-	item = g_list_nth(GTK_MENU_SHELL(shell)->children, GTK_HEX(mdi->active_view)->group_type / 2)->data;
+	shell = gnome_app_find_menu_pos(app->menubar, _(GROUP_MENU_PATH), &pos);
+
+	group_item = GTK_HEX(mdi->active_view)->group_type / 2;
+	shell = gnome_app_find_menu_pos(shell, _(group_type_label[group_item]), &pos);
+
+	item = g_list_nth(GTK_MENU_SHELL(shell)->children, pos - 1)->data;
 	
 	gtk_menu_shell_activate_item(GTK_MENU_SHELL(shell), item, TRUE);
 
