@@ -43,6 +43,10 @@ extern GnomeUIInfo help_menu[], file_menu[], view_menu[], main_menu[];
 
 #define NUM_MDI_MODES 4
 
+#define CHILD_MENU_PATH "File"
+#define CHILD_LIST_PATH "Files/"
+#define GROUP_MENU_PATH "Edit/Group Data As/"
+
 typedef struct _PropertyUI {
 	GnomePropertyBox *pbox;
 	GtkRadioButton *mdi_type[NUM_MDI_MODES];
@@ -116,6 +120,7 @@ void create_replace_dialog(ReplaceDialog *);
 void create_jump_dialog(JumpDialog *);
 void create_converter(Converter *);
 void create_prefs_dialog(PropertyUI *);
+void create_dialog_title(GtkWidget *, gchar *);
 
 gint ask_user(GnomeMessageBox *);
 
