@@ -425,6 +425,8 @@ static void hex_expose(GtkWidget *w, GdkEventExpose *event, GtkHex *gh) {
 	imax = (event->area.y + event->area.height) / gh->char_height;
 	if((event->area.y + event->area.height) % gh->char_height)
 		imax++;
+
+	imax = MAX(imax, gh->vis_lines);
 	
 	render_hex_lines(gh, imin, imax);
 }
@@ -437,6 +439,8 @@ static void ascii_expose(GtkWidget *w, GdkEventExpose *event, GtkHex *gh) {
 	if((event->area.y + event->area.height) % gh->char_height)
 		imax++;
 	
+	imax = MAX(imax, gh->vis_lines);
+
 	render_ascii_lines(gh, imin, imax);
 }
 
@@ -508,12 +512,12 @@ static void recalc_displays(GtkHex *gh, guint width, guint height) {
 	if(gh->cpl % gh->group_type == 0)
 		xcpl--;
 	gh->xdisp_width = xcpl*gh->char_width + 1;
-	
+
 	if(gh->disp_buffer)
-		free(gh->disp_buffer);
-	
-	gh->disp_buffer = malloc(xcpl * (gh->vis_lines + 3));
+		g_free(gh->disp_buffer);
 	
+	gh->disp_buffer = g_malloc(xcpl * (gh->vis_lines + 3));
+
 	/* adjust the scrollbar and display position to
 	   new sizes */
 	gh->adj->value = MIN(gh->top_line*old_cpl / gh->cpl, gh->lines - gh->vis_lines);
@@ -775,14 +779,14 @@ static void gtk_hex_real_data_changed(GtkHex *gh, gpointer data) {
 	render_ascii_lines(gh, start_line, end_line);
 }
 
-static void gtk_hex_destroy(GtkObject *o) {
+static void gtk_hex_finalize(GtkObject *o) {
 	GtkHex *gh = GTK_HEX(o);
 	
 	if(gh->disp_buffer)
 		free(gh->disp_buffer);
 	
-	if(GTK_OBJECT_CLASS(parent_class)->destroy)
-		(* GTK_OBJECT_CLASS(parent_class)->destroy)(o);  
+	if(GTK_OBJECT_CLASS(parent_class)->finalize)
+		(* GTK_OBJECT_CLASS(parent_class)->finalize)(o);  
 }
 
 static gint gtk_hex_key_press(GtkWidget *w, GdkEventKey *event) {
@@ -976,10 +980,11 @@ static void gtk_hex_class_init(GtkHexClass *klass) {
 	
 	GTK_WIDGET_CLASS(klass)->draw = gtk_hex_draw;
 	GTK_WIDGET_CLASS(klass)->size_allocate = gtk_hex_size_allocate;
+	GTK_WIDGET_CLASS(klass)->size_request = gtk_hex_size_request;
 	GTK_WIDGET_CLASS(klass)->expose_event = gtk_hex_expose;
 	GTK_WIDGET_CLASS(klass)->key_press_event = gtk_hex_key_press;
 	GTK_WIDGET_CLASS(klass)->realize = gtk_hex_realize;
-	GTK_OBJECT_CLASS(klass)->destroy = gtk_hex_destroy;
+	GTK_OBJECT_CLASS(klass)->finalize = gtk_hex_finalize;
 	
 	parent_class = gtk_type_class (gtk_fixed_get_type ());
 }
@@ -1163,12 +1168,8 @@ guchar gtk_hex_get_byte(GtkHex *gh, guint offset) {
  * sets data group type (see GROUP_* defines in gtkhex.h)
  */
 void gtk_hex_set_group_type(GtkHex *gh, guint gt) {
-	GtkAllocation alloc;
-	
-	memcpy(&alloc, &(GTK_WIDGET(gh)->allocation), sizeof(GtkAllocation));
-	
 	gh->group_type = gt;
-	gtk_signal_emit_by_name(GTK_OBJECT(gh), "size_allocate", &alloc);
+	gtk_widget_queue_resize(GTK_WIDGET(gh));
 }
 
 void gtk_hex_data_changed(GtkHex *gh, gint start, gint end) {
