@@ -23,8 +23,6 @@
 
 #include <config.h>
 #include <gnome.h>
-#include <getopt.h>
-
 #include "gnome-support.h"
 #include "ghex.h"
 #include "callbacks.h"
@@ -34,38 +32,37 @@ GnomeMDI *mdi;
 gint mdi_mode = GNOME_MDI_DEFAULT_MODE;
 
 int main(int argc, char **argv) {
-  GnomeClient *client;
-  HexDocument *doc;
-  char **cl_files;
-  poptContext ctx;
-  int i;
+	GnomeClient *client;
+	HexDocument *doc;
+	char **cl_files;
+	poptContext ctx;
 
-  bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-  textdomain(PACKAGE);
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain(PACKAGE);
 
-  gnome_init_with_popt_table("ghex", VERSION, argc, argv, options, 0, &ctx);
+	gnome_init_with_popt_table("ghex", VERSION, argc, argv, options, 0, &ctx);
 
-  client = gnome_master_client();
+	client = gnome_master_client();
 
-  gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
-		      GTK_SIGNAL_FUNC (save_state), (gpointer) argv[0]);
+	gtk_signal_connect (GTK_OBJECT (client), "save_yourself",
+						GTK_SIGNAL_FUNC (save_state), (gpointer) argv[0]);
+	gtk_signal_connect (GTK_OBJECT (client), "die",
+						GTK_SIGNAL_FUNC (client_die), NULL);
 
-  if(just_exit) {
-    discard_session(just_exit);
-  } else {
     mdi = GNOME_MDI(gnome_mdi_new("ghex", "GHex"));
 
     /* set up MDI menus */
     gnome_mdi_set_menubar_template(mdi, main_menu);
 
     /* and document menu and document list paths */
-    gnome_mdi_set_child_menu_path(mdi, _("File"));
-    gnome_mdi_set_child_list_path(mdi, _("Files/"));
+    gnome_mdi_set_child_menu_path(mdi, _(CHILD_MENU_PATH));
+    gnome_mdi_set_child_list_path(mdi, _(CHILD_LIST_PATH));
 
     /* connect signals */
     gtk_signal_connect(GTK_OBJECT(mdi), "remove_child", GTK_SIGNAL_FUNC(remove_doc_cb), NULL);
     gtk_signal_connect(GTK_OBJECT(mdi), "destroy", GTK_SIGNAL_FUNC(cleanup_cb), NULL);
     gtk_signal_connect(GTK_OBJECT(mdi), "view_changed", GTK_SIGNAL_FUNC(view_changed_cb), NULL);
+	gtk_signal_connect(GTK_OBJECT(mdi), "child_changed", GTK_SIGNAL_FUNC(child_changed_cb), NULL);
 	gtk_signal_connect(GTK_OBJECT(mdi), "app_created", GTK_SIGNAL_FUNC(customize_app_cb), NULL);
 
     /* load preferences */
@@ -75,21 +72,20 @@ int main(int argc, char **argv) {
 
     /* restore state from previous session */
     if (GNOME_CLIENT_CONNECTED (client)) {
-      /* Get the client, that may hold the configuration for this
-         program.  */
-      GnomeClient *cloned= gnome_cloned_client ();
 
-      if (cloned) {
-        restarted = 1;
+		gnome_config_push_prefix (gnome_client_get_config_prefix (client));
 
-        gnome_config_push_prefix (gnome_client_get_config_prefix (cloned));
-        gnome_mdi_restore_state (mdi, "Session", (GnomeMDIChildCreator)hex_document_new_from_config);
-        gnome_config_pop_prefix ();
-      }
-    }
+		restarted= gnome_config_get_bool ("General/saved_session=0");
+		
+		if (restarted)
+			restarted = gnome_mdi_restore_state (mdi, "Session", (GnomeMDIChildCreator)hex_document_new_from_config);
+				
 
-	if(!restarted)
-		  gnome_mdi_open_toplevel(mdi);
+		gnome_config_pop_prefix ();
+	}
+
+	if (!restarted)
+		gnome_mdi_open_toplevel(mdi);
 	
     cl_files = poptGetArgs(ctx);
 	
@@ -105,7 +101,6 @@ int main(int argc, char **argv) {
 	
     /* and here we go... */
     gtk_main();
-  }
 
-  return 0;
+	return 0;
 }
