@@ -33,7 +33,7 @@ GnomeUIInfo file_menu[] = {
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'O', GDK_CONTROL_MASK, NULL },
 	{ GNOME_APP_UI_ITEM, N_("_Save"), N_("Save buffer "), save_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 'S', GDK_CONTROL_MASK, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Save _as..."), N_("Save buffer under a different file name"), save_as_cb, NULL, NULL,
+	{ GNOME_APP_UI_ITEM, N_("Save _As..."), N_("Save buffer under a different file name"), save_as_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE_AS, 0, 0, NULL },
 	{ GNOME_APP_UI_ITEM, N_("_Revert"), N_("Revert buffer"), revert_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REVERT, 'R', GDK_CONTROL_MASK, NULL },
@@ -41,7 +41,7 @@ GnomeUIInfo file_menu[] = {
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE, 0, 0, NULL },
 	{ GNOME_APP_UI_SEPARATOR, NULL, NULL, NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("Open _Converter..."), N_("Open base conversion dialog"), converter_cb, NULL, NULL,
+	{ GNOME_APP_UI_ITEM, N_("Open Con_verter..."), N_("Open base conversion dialog"), converter_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
 	{ GNOME_APP_UI_SEPARATOR, NULL, NULL, NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
@@ -49,8 +49,8 @@ GnomeUIInfo file_menu[] = {
 	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF, 'P', GDK_CONTROL_MASK, NULL },
 	{ GNOME_APP_UI_SEPARATOR, NULL, NULL, NULL, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL },
-	{ GNOME_APP_UI_ITEM, N_("_Exit"), N_("Exit GHex"), quit_app_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'Q', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, N_("E_xit"), N_("Exit GHex"), quit_app_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', GDK_CONTROL_MASK, NULL },
 	{ GNOME_APP_UI_ENDOFINFO }
 };
 
@@ -172,7 +172,7 @@ void create_find_dialog(FindDialog *dialog) {
 	gtk_signal_connect(GTK_OBJECT(dialog->window), "delete_event",
 					   GTK_SIGNAL_FUNC(delete_event_cb), &dialog->window);
 	
-	gtk_window_set_title(GTK_WINDOW(dialog->window), _("GHex: Find Data"));
+	create_dialog_title(dialog->window, _("GHex (%s): Find Data"));
 	
 	dialog->f_string = gtk_entry_new();
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), dialog->f_string,
@@ -189,7 +189,7 @@ void create_find_dialog(FindDialog *dialog) {
 			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(dialog->type_button[i]), TRUE);
 		
 		gtk_signal_connect(GTK_OBJECT(dialog->type_button[i]), "clicked",
-						   GTK_SIGNAL_FUNC(set_find_type_cb), (gpointer)i);
+						   GTK_SIGNAL_FUNC(set_find_type_cb), GINT_TO_POINTER(i));
 		
 		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), dialog->type_button[i],
 						   TRUE, TRUE, 0);
@@ -232,7 +232,7 @@ void create_replace_dialog(ReplaceDialog *dialog) {
 	gtk_signal_connect(GTK_OBJECT(dialog->window), "delete_event",
 					   GTK_SIGNAL_FUNC(delete_event_cb), &dialog->window);
 	
-	gtk_window_set_title(GTK_WINDOW(dialog->window), _("GHex: Find & Replace Data"));
+	create_dialog_title(dialog->window, _("GHex (%s): Find & Replace Data"));
 	
 	dialog->f_string = gtk_entry_new();
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), dialog->f_string,
@@ -254,7 +254,7 @@ void create_replace_dialog(ReplaceDialog *dialog) {
 			gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(dialog->type_button[i]), TRUE);
 		
 		gtk_signal_connect(GTK_OBJECT(dialog->type_button[i]), "clicked",
-						   GTK_SIGNAL_FUNC(set_replace_type_cb), (gpointer)i);
+						   GTK_SIGNAL_FUNC(set_replace_type_cb), GINT_TO_POINTER(i));
 		
 		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), dialog->type_button[i],
 						   TRUE, TRUE, 0);
@@ -295,12 +295,29 @@ void create_replace_dialog(ReplaceDialog *dialog) {
 	gtk_box_set_spacing(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), 2);
 }
 
+void create_dialog_title(GtkWidget *window, gchar *title) {
+	gchar *full_title;
+
+	if(!window)
+		return;
+
+	if(mdi->active_child)
+		full_title = g_strdup_printf(title, mdi->active_child->name);
+	else
+		full_title = g_strdup_printf(title, "");
+
+	if(full_title) {
+		gtk_window_set_title(GTK_WINDOW(window), full_title);
+		g_free(full_title);
+	}
+}
+
 void create_jump_dialog(JumpDialog *dialog) {
 	dialog->window = gtk_dialog_new();
 	gtk_signal_connect(GTK_OBJECT(dialog->window), "delete_event",
 					   GTK_SIGNAL_FUNC(delete_event_cb), &dialog->window);
 	
-	gtk_window_set_title(GTK_WINDOW(dialog->window), _("GHex: Jump To Byte"));
+	create_dialog_title(dialog->window, _("GHex (%s): Jump To Byte"));
 	
 	dialog->int_entry = gtk_entry_new();
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog->window)->vbox), dialog->int_entry,
