@@ -64,7 +64,15 @@ unselect_row(GtkCList *clist, gint row, gint column, GdkEventButton *event)
 	GtkWidget *menu;
 
 	if (gtk_clist_get_row_data(clist, row) != cur_proj) return;
-	if ((!event) || (event->button != 3)) {
+	if (event) {
+		if (event->button == 3) {
+			/* make sure the project keeps selection */
+			gtk_clist_select_row(GTK_CLIST(glist), row, column);
+			menu = menus_get_popup();
+			gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
+				       3, event->time);
+			return;
+		}
 		if (event->type == GDK_2BUTTON_PRESS) {
 			cur_proj_set(gtk_clist_get_row_data(clist, row));
 			gtk_clist_select_row(GTK_CLIST(glist), cur_proj->row,
@@ -72,13 +80,8 @@ unselect_row(GtkCList *clist, gint row, gint column, GdkEventButton *event)
 			prop_dialog(cur_proj);
 			return;
 		}
-		cur_proj_set(NULL);
-		return;
 	}
-	/* make sure the project keeps selection */
-	gtk_clist_select_row(GTK_CLIST(glist), row, column);
-	menu = menus_get_popup();
-	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, 3, event->time);
+	cur_proj_set(NULL);
 }
 
 
@@ -126,7 +129,7 @@ clist_header_hack(GtkWidget *window, GtkWidget *w)
 GtkWidget *
 create_clist(void)
 {
-	GtkWidget *w;
+	GtkWidget *w, *sw;
 	char *titles[4] = {
 		N_("Total"),
 		N_("Today"),
@@ -145,8 +148,14 @@ create_clist(void)
 	gtk_clist_set_column_justification(GTK_CLIST(w), TOTAL_COL, GTK_JUSTIFY_CENTER);
 	gtk_clist_set_column_justification(GTK_CLIST(w), TIME_COL,  GTK_JUSTIFY_CENTER);
 	gtk_clist_column_titles_active(GTK_CLIST(w));
-	gtk_clist_set_policy(GTK_CLIST(w),
-			     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+
+	sw = gtk_scrolled_window_new (NULL, NULL);
+	gtk_container_add (GTK_CONTAINER (sw), w);
+	gtk_scrolled_window_set_policy (
+		GTK_SCROLLED_WINDOW (sw),
+		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_widget_show_all (sw);
+
 	gtk_signal_connect(GTK_OBJECT(w), "select_row",
 			   GTK_SIGNAL_FUNC(select_row), NULL);
 	gtk_signal_connect(GTK_OBJECT(w), "click_column",
