@@ -154,7 +154,7 @@ session_save_state (GnomeClient *client, gint phase,
     GnomeLessApp * a = tmp->data;
     gchar * s
       = gnome_geometry_string( GTK_WIDGET(a->app)->window );
-    argv[argc] = g_copy_strings("--geometry=", s, NULL);
+    argv[argc] = g_strconcat("--geometry=", s, NULL);
     g_free(s);
     free_me = g_list_prepend(free_me, argv[argc]);
     ++argc;
@@ -275,7 +275,7 @@ int main ( int argc, char ** argv )
 
 static GnomeUIInfo help_menu[] = {
   GNOMEUIINFO_HELP(APPNAME),
-  {GNOME_APP_UI_ITEM, N_("About..."), 
+  {GNOME_APP_UI_ITEM, N_("_About..."), 
    N_("Tell about this application"), 
    about_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL },
@@ -284,36 +284,43 @@ static GnomeUIInfo help_menu[] = {
 
 static GnomeUIInfo file_menu[] = {
   {GNOME_APP_UI_ITEM, 
-   N_("New Window"), N_("New text viewer window"), 
+   N_("_New Window"), N_("New text viewer window"), 
    new_app_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'n', 
    GDK_CONTROL_MASK, NULL },
   {GNOME_APP_UI_ITEM, 
-   N_("Open..."), N_("Open a new file in this window"), 
+   N_("_Open..."), N_("Open a new file in this window"), 
    open_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 'o', 
    GDK_CONTROL_MASK, NULL },
   {GNOME_APP_UI_ITEM, 
-   N_("Save As..."), N_("Save file to disk"), 
+   N_("Save _As..."), N_("Save file to disk"), 
    save_as_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 's', 
    GDK_CONTROL_MASK, NULL },
-  {GNOME_APP_UI_ITEM, N_("Close"), 
+  {GNOME_APP_UI_ITEM, N_("_Close"), 
    N_("Close this window"),
    close_cb, NULL, NULL,
    GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'c', 
    GDK_CONTROL_MASK, NULL },
   GNOMEUIINFO_SEPARATOR,
-  {GNOME_APP_UI_ITEM, N_("Exit"), 
+#if 0
+  {GNOME_APP_UI_ITEM, N_("_Preferences..."), 
+   N_("Change application preferences"),
+   preferences_cb, NULL, NULL,
+   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF, 'p', 
+   GDK_CONTROL_MASK, NULL },
+#endif
+  {GNOME_APP_UI_ITEM, N_("E_xit"), 
    N_("Quit the application"),
    exit_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'q', 
+   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', 
    GDK_CONTROL_MASK, NULL },
   GNOMEUIINFO_END
 };
 
 static GnomeUIInfo view_menu[] = {
-  {GNOME_APP_UI_TOGGLEITEM, N_("Fixed Font"), 
+  {GNOME_APP_UI_TOGGLEITEM, N_("_Fixed Font"), 
    N_("Display text with a fixed font"),
    fixed_cb, NULL, NULL,
    0, 0, 'f', 
@@ -321,20 +328,10 @@ static GnomeUIInfo view_menu[] = {
   GNOMEUIINFO_END
 };
 
-static GnomeUIInfo prefs_menu[] = {
-  {GNOME_APP_UI_ITEM, N_("Preferences..."), 
-   N_("Change application preferences"),
-   preferences_cb, NULL, NULL,
-   GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF, 'p', 
-   GDK_CONTROL_MASK, NULL },
-  GNOMEUIINFO_END
-};
-
 static GnomeUIInfo main_menu[] = {
-  GNOMEUIINFO_SUBTREE (N_("File"), file_menu),
-  GNOMEUIINFO_SUBTREE (N_("View"), view_menu),
-  GNOMEUIINFO_SUBTREE (N_("Preferences"), prefs_menu),
-  GNOMEUIINFO_SUBTREE (N_("Help"), help_menu),
+  GNOMEUIINFO_SUBTREE (N_("_File"), file_menu),
+  GNOMEUIINFO_SUBTREE (N_("_View"), view_menu),
+  GNOMEUIINFO_SUBTREE (N_("_Help"), help_menu),
   GNOMEUIINFO_END
 };
 
@@ -455,7 +452,7 @@ gless_app_show_file(GnomeLessApp * app, const gchar * filename)
   if ( ! g_file_exists(filename) ) {
     gchar * s;
     s = 
-      g_copy_strings(_("No such file or directory:\n"),
+      g_strconcat(_("No such file or directory:\n"),
                      filename, NULL);
     gless_show_file_error(app, s);
     g_free(s);
@@ -468,11 +465,11 @@ gless_app_show_file(GnomeLessApp * app, const gchar * filename)
        (strcmp(&filename[len - 2], ".Z" ) == 0) ) {
     gchar * s;
     if ( (s = gnome_is_program_in_path("zcat")) ) {
-      gchar * c = g_copy_strings(s, " ", filename, NULL);
+      gchar * c = g_strconcat(s, " ", filename, NULL);
       g_free(s);
       if ( ! gnome_less_show_command(GNOME_LESS(app->less), c) ) {
         gchar * err = 
-          g_copy_strings(_("Failed to decompress and display the file:\n"),
+          g_strconcat(_("Failed to decompress and display the file:\n"),
                          filename, "\n", g_unix_error_string(errno), NULL);
         gless_show_file_error(app, err);
         g_free(err);
@@ -491,7 +488,7 @@ gless_app_show_file(GnomeLessApp * app, const gchar * filename)
   else {
     if ( ! gnome_less_show_file(GNOME_LESS(app->less), filename) ) {
       gchar * err = 
-        g_copy_strings(_("Error loading file:\n"), filename,
+        g_strconcat(_("Error loading file:\n"), filename,
                        "\n", g_unix_error_string(errno), NULL);
       gless_show_file_error(app, err);
       g_free(err);
@@ -556,7 +553,7 @@ static gboolean gless_app_save(GnomeLessApp * app, const gchar * path)
 
   gnome_appbar_pop (app->appbar);
 
-  s = g_copy_strings(_("Failed to write file:\n"), path, 
+  s = g_strconcat(_("Failed to write file:\n"), path, 
                      "\n", g_unix_error_string(errno), NULL);
 
   gnome_app_error(GNOME_APP(app->app), s);
