@@ -19,11 +19,12 @@
  * USA
  */
 
+#include <config.h>
 #include "info.h"
 #include <unistd.h>
 #include <string.h> /* memset */
 #include <sys/utsname.h>
-
+#include <errno.h>
 
 #define DEBIAN_STRING "Debian GNU/Linux"
 #define REDHAT_STRING "Red Hat Linux"
