@@ -57,7 +57,7 @@ void fill_clist(GtkCList * list,
 
     row[0] = col1_items[i];
     row[1] = col2_items[i];
-    gtk_clist_append(list, (gchar **)row);
+    gtk_clist_append(list, row);
 
     /* If the string is longer than any previous ones,
        increase the column width */
@@ -142,8 +142,6 @@ GtkWidget * create_clist(const gchar * titles[])
   /* Fixme, eventually you might could select an item 
      for cut and paste, or some other effect. */
   gtk_clist_set_selection_mode(list, GTK_SELECTION_BROWSE);
-  gtk_clist_set_policy(list, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-
   gtk_clist_column_titles_passive(list);
 
   return GTK_WIDGET(list);
