@@ -111,25 +111,30 @@ create_disk_box(const gchar ** fs_info, gdouble * percent_full)
 static void fill_disk_page(GtkWidget * box)
 {
   GtkWidget * disk_box;
+  GtkWidget * viewport;
   GtkWidget * scrolled_win;
   GtkWidget * scrolled_box;
-  GtkWidget * frame;
   GList * tmp1, *tmp2;
   
-  frame = gtk_frame_new(_("Mounted filesystems"));
-
   scrolled_win = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
-                                  GTK_POLICY_AUTOMATIC, 
+                                  GTK_POLICY_NEVER, 
                                   GTK_POLICY_AUTOMATIC);
-  gtk_container_border_width(GTK_CONTAINER(scrolled_win), GNOME_PAD);
-  gtk_container_add(GTK_CONTAINER(frame), scrolled_win);
+  gtk_container_border_width(GTK_CONTAINER(scrolled_win), 0);
+  gtk_box_pack_start(GTK_BOX(box), scrolled_win, TRUE, TRUE, 0);
 
   scrolled_box = gtk_vbox_new(FALSE, GNOME_PAD_SMALL);
   gtk_container_border_width(GTK_CONTAINER(scrolled_box), GNOME_PAD_SMALL);
-  gtk_container_add(GTK_CONTAINER(scrolled_win), scrolled_box);
-  gtk_box_pack_start(GTK_BOX(box), frame, TRUE, TRUE, 0);
-  
+
+  viewport = gtk_viewport_new(gtk_scrolled_window_get_hadjustment
+                              (GTK_SCROLLED_WINDOW(scrolled_win)),
+                              gtk_scrolled_window_get_vadjustment
+                              (GTK_SCROLLED_WINDOW(scrolled_win)));
+  gtk_viewport_set_shadow_type(GTK_VIEWPORT(viewport), GTK_SHADOW_ETCHED_IN);
+  gtk_container_add (GTK_CONTAINER (scrolled_win), viewport);
+  gtk_widget_show (viewport);
+
+  gtk_container_add (GTK_CONTAINER (viewport), scrolled_box);
   
   tmp1 = filesystems;
   tmp2 = filesystems_percent_full;
@@ -201,12 +206,9 @@ static void fill_mem_page(GtkWidget * box)
 static void fill_cpuinfo_page(GtkWidget * box)
 {
   GtkWidget * clist;
-  GtkWidget * vbox;
+  GtkWidget * scrolled_win;
   int i;
 
-  vbox = gtk_vbox_new(FALSE, GNOME_PAD);
-  gtk_container_add(GTK_CONTAINER(box), vbox);
-
   for (i = 0; i < sysinfo->ncpu; i++) {
     gchar buffer [BUFSIZ], *titles [2];
     
@@ -218,10 +220,15 @@ static void fill_cpuinfo_page(GtkWidget * box)
     titles [1] = N_("Value");
 
     clist = create_clist(titles);
-    gtk_box_pack_start(GTK_BOX(vbox), clist, TRUE, TRUE, GNOME_PAD);
     gtk_clist_freeze(GTK_CLIST(clist));
     fill_clist_from_glibtop_entry(GTK_CLIST(clist), &sysinfo->cpuinfo [i]);
     gtk_clist_thaw(GTK_CLIST(clist));
+
+    scrolled_win = gtk_scrolled_window_new (NULL, NULL);
+    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_win),
+                                    GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+    gtk_container_add (GTK_CONTAINER (scrolled_win), clist);
+    gtk_box_pack_start(GTK_BOX(box), scrolled_win, TRUE, TRUE, 0);
   }
 }
 
@@ -307,7 +314,7 @@ void load_fsinfo()
     percent_full = NULL;
 
     fs_info[fs_description] = 
-      g_copy_strings(_("Mount Point: "), mount_list [i].mountdir, 
+      g_strconcat(_("Mount Point: "), mount_list [i].mountdir, 
                      _("    Device: "), mount_list [i].devname,
                      _("    Filesystem Type: "), mount_list [i].type,
                      NULL);
